@@ -520,10 +520,18 @@ def apply_screenshot_masks(screenshot_bitmap, bitmap_masks):
     if bitmap_masks != []:
         for each_mask in bitmap_masks:
             for i in range(each_mask['height']):
-                screenshot_bitmap[each_mask['row'] + i] = screenshot_bitmap[each_mask['row'] + i][:each_mask['column']] \
-                                                        +''.zfill(each_mask['width']) \
-                                                        +screenshot_bitmap[each_mask['row'] + i][each_mask['column'] + each_mask['width']:]
-    return screenshot_bitmap                               
+                if each_mask['name'] != 'progress_bar':
+                    screenshot_bitmap[each_mask['row'] + i] = \
+                        screenshot_bitmap[each_mask['row'] + i][:each_mask['column']] \
+                        +screenshot_bitmap[each_mask['row']][each_mask['column']] * each_mask['width'] \
+                        +screenshot_bitmap[each_mask['row'] + i][each_mask['column'] + each_mask['width']:]
+                else:
+                    screenshot_bitmap[each_mask['row'] + i] = \
+                        screenshot_bitmap[each_mask['row'] + i][:each_mask['column']] \
+                        +'0' * each_mask['width'] \
+                        +screenshot_bitmap[each_mask['row'] + i][each_mask['column'] + each_mask['width']:]
+    
+    return screenshot_bitmap
 
 
 def bitmap_to_image(bitmap_str_list, image_path, bitmap_masks=[]):
